@@ -5,7 +5,7 @@ use Exporter;
 use File::Spec;
 use ExtUtils::ParseXS::Constants ();
 
-our $VERSION = '3.58';
+our $VERSION = '3.60';
 
 our (@ISA, @EXPORT_OK);
 @ISA = qw(Exporter);
@@ -64,94 +64,75 @@ They are documented here for the benefit of future maintainers of this module.
 
 =item * Purpose
 
-Provide a list of filepaths where F<typemap> files may be found.  The
-filepaths -- relative paths to files (not just directory paths) -- appear in this list in lowest-to-highest priority.
+Returns a standard list of filepaths where F<typemap> files may be found.
+This will typically be something like:
 
-The highest priority is to look in the current directory.  
+        map("$_/ExtUtils/typemap", reverse @INC),
+        qw(
+            ../../../../lib/ExtUtils/typemap
+            ../../../../typemap
+            ../../../lib/ExtUtils/typemap
+            ../../../typemap
+            ../../lib/ExtUtils/typemap
+            ../../typemap
+            ../lib/ExtUtils/typemap
+            ../typemap
+            typemap
+        )
 
-  'typemap'
+but the style of the pathnames may vary with OS. Note that the value to
+use for C<@INC> is passed as an array reference, and can be something
+other than C<@INC> itself.
 
-The second and third highest priorities are to look in the parent of the
-current directory and a directory called F<lib/ExtUtils> underneath the parent
-directory.
+Pathnames are returned in the order they are expected to be processed;
+this means that later files will update or override entries found in
+earlier files. So in particular, F<typemap> in the current directory has
+highest priority. C<@INC> is searched in reverse order so that earlier
+entries in C<@INC> are processed later and so have higher priority.
 
-  '../typemap',
-  '../lib/ExtUtils/typemap',
-
-The fourth through ninth highest priorities are to look in the corresponding
-grandparent, great-grandparent and great-great-grandparent directories.
-
-  '../../typemap',
-  '../../lib/ExtUtils/typemap',
-  '../../../typemap',
-  '../../../lib/ExtUtils/typemap',
-  '../../../../typemap',
-  '../../../../lib/ExtUtils/typemap',
-
-The tenth and subsequent priorities are to look in directories named
-F<ExtUtils> which are subdirectories of directories found in C<@INC> --
-I<provided> a file named F<typemap> actually exists in such a directory.
-Example:
-
-  '/usr/local/lib/perl5/5.10.1/ExtUtils/typemap',
-
-However, these filepaths appear in the list returned by
-C<standard_typemap_locations()> in reverse order, I<i.e.>, lowest-to-highest.
-
-  '/usr/local/lib/perl5/5.10.1/ExtUtils/typemap',
-  '../../../../lib/ExtUtils/typemap',
-  '../../../../typemap',
-  '../../../lib/ExtUtils/typemap',
-  '../../../typemap',
-  '../../lib/ExtUtils/typemap',
-  '../../typemap',
-  '../lib/ExtUtils/typemap',
-  '../typemap',
-  'typemap'
+The values of C<-typemap> switches are not used here; they should be added
+by the caller to the list of pathnames returned by this function.
 
 =item * Arguments
 
-  my @stl = standard_typemap_locations( \@INC );
+  my @stl = standard_typemap_locations(\@INC);
 
-Reference to C<@INC>.
+A single argument: a reference to an array to use as if it were C<@INC>.
 
 =item * Return Value
 
-Array holding list of directories to be searched for F<typemap> files.
+A list of F<typemap> pathnames.
 
 =back
 
 =cut
 
-SCOPE: {
-  my @tm_template;
+sub standard_typemap_locations {
+  my $include_ref = shift;
 
-  sub standard_typemap_locations {
-    my $include_ref = shift;
+  my @tm;
 
-    if (not @tm_template) {
-      @tm_template = qw(typemap);
-
-      my $updir = File::Spec->updir();
-      foreach my $dir (
-          File::Spec->catdir(($updir) x 1),
-          File::Spec->catdir(($updir) x 2),
-          File::Spec->catdir(($updir) x 3),
-          File::Spec->catdir(($updir) x 4),
-      ) {
-        unshift @tm_template, File::Spec->catfile($dir, 'typemap');
-        unshift @tm_template, File::Spec->catfile($dir, lib => ExtUtils => 'typemap');
-      }
-    }
-
-    my @tm = @tm_template;
-    foreach my $dir (@{ $include_ref}) {
-      my $file = File::Spec->catfile($dir, ExtUtils => 'typemap');
-      unshift @tm, $file if -e $file;
-    }
-    return @tm;
+  # See function description above for why 'reverse' is used here.
+  foreach my $dir (reverse @{$include_ref}) {
+    my $file = File::Spec->catfile($dir, ExtUtils => 'typemap');
+    push @tm, $file;
   }
-} # end SCOPE
+
+  my $updir = File::Spec->updir();
+  foreach my $dir (
+      File::Spec->catdir(($updir) x 4),
+      File::Spec->catdir(($updir) x 3),
+      File::Spec->catdir(($updir) x 2),
+      File::Spec->catdir(($updir) x 1),
+  ) {
+    push @tm, File::Spec->catfile($dir, lib => ExtUtils => 'typemap');
+    push @tm, File::Spec->catfile($dir, 'typemap');
+  }
+
+  push @tm, 'typemap';
+
+  return @tm;
+}
 
 =head2 C<trim_whitespace()>
 
@@ -245,18 +226,21 @@ sub valid_proto_string {
 
 =item * Purpose
 
-Process all typemap files.
+Process all typemap files. Reads in any typemap files specified explicitly
+with C<-typemap> switches or similar, plus any typemap files found in
+standard locations relative to C<@INC> and the current directory.
 
 =item * Arguments
 
   my $typemaps_object = process_typemaps( $args{typemap}, $pwd );
 
-List of two elements:  C<typemap> element from C<%args>; current working
-directory.
+The first argument is the C<typemap> element from C<%args>; the second is
+the current working directory (which is only needed for error messages).
 
 =item * Return Value
 
-Upon success, returns an L<ExtUtils::Typemaps> object.
+Upon success, returns an L<ExtUtils::Typemaps> object which contains the
+accumulated results of all processed typemap files.
 
 =back
 
@@ -265,13 +249,13 @@ Upon success, returns an L<ExtUtils::Typemaps> object.
 sub process_typemaps {
   my ($tmap, $pwd) = @_;
 
-  my @tm = ref $tmap ? @{$tmap} : ($tmap);
+  my @tm = standard_typemap_locations( \@INC );
 
-  foreach my $typemap (@tm) {
+  my @explicit = ref $tmap ? @{$tmap} : ($tmap);
+  foreach my $typemap (@explicit) {
     die "Can't find $typemap in $pwd\n" unless -r $typemap;
   }
-
-  push @tm, standard_typemap_locations( \@INC );
+  push @tm, @explicit;
 
   require ExtUtils::Typemaps;
   my $typemap = ExtUtils::Typemaps->new;
